@@ -120,6 +120,8 @@ class inject:
         @functools.wraps(obj)
         async def f(*args, **kwargs):
             dep = require(self.injected)
+            if hasattr(dep, 'as_context'):
+                dep = dep.as_context()
             async with _ensure_async_context(dep, self.scope) as ctx:
                 kwargs[self.attname] = ctx
                 return await obj(*args, **kwargs)
